c3errors

Module c3errors |
[hide private]
[frames] | no frames]

## Source Code for Module c3errors

     1
     2  import exceptions
     3
     4 -class C3Exception(Exception):
     5      text = ""
     6
     7 -    def __init__(self, text="None"):
     8          self.reason = text
     9
    10 -    def __str__(self):
    11          return "Cheshire3 Exception: " + self.reason
    12
    13 -class ConfigFileException(C3Exception):
    14      pass
    15
    16 -class FileDoesNotExistException(C3Exception):
    17      pass
    18
    19 -class ObjectDoesNotExistException(C3Exception):
    20      pass
    21
    22 -class ObjectAlreadyExistsException(C3Exception):
    23      pass
    24
    25 -class PermissionException(C3Exception):
    26      pass
    27
    28 -class ExternalSystemException(C3Exception):
    29      pass
    30